// SPDX-FileCopyrightText: 2023 g10 code Gmbh
// SPDX-Contributor: Carl Schwan <carl.schwan@gnupg.com>
// SPDX-License-Identifier: GPL-2.0-or-later

#include "controllers/emailcontroller.h"

#include <QHttpServer>
#include <QHttpServerResponse>
#include <QApplication>
#include <QJsonDocument>
#include <QJsonObject>
#include <QJsonArray>
#include <QUuid>
#include <QTimer>
#include <QNetworkReply>
#include <KLocalizedString>
#include <Libkleo/KeyCache>

#include "websocketclient.h"
#include "webserver.h"
#include "qnam.h"

using namespace Qt::Literals::StringLiterals;
using namespace std::chrono;

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setQuitOnLastWindowClosed(false);

    KLocalizedString::setApplicationDomain(QByteArrayLiteral("gpgol"));

    QObject::connect(qnam, &QNetworkAccessManager::sslErrors, qnam, [](QNetworkReply *reply, const QList<QSslError> &) {
        reply->ignoreSslErrors();
    });

    WebServer server;
    server.run();
    if (!server.running()) {
        qWarning() << "Server failed to listen on a port.";
        return 1;
    }
    const auto port = server.port();

    WebsocketClient::self(QUrl(u"wss://localhost:5657/"_s), port);
    auto keyCache = Kleo::KeyCache::mutableInstance();
    keyCache->startKeyListing();

    return app.exec();
}
